##  Business Value and Usage of AI Agents
If you use the [AI agent hub](https://help.sap.com/docs/leanix/ea/ai-agent-hub?locale=en-US&state=PRODUCTION&version=CLOUD "Discover and manage AI agents across the organization."), you can analyze the business value and usage of AI agents with dedicated reports. For a complete list of predefined reports, see [Reports for AI Agents](https://help.sap.com/docs/leanix/ea/reports-for-ai-agents?locale=en-US&state=PRODUCTION&version=CLOUD "Use reports to get an overview of AI agents in your enterprise architecture landscape.").
The business value is calculated automatically. Once you activate the AI agent extension, dedicated calculation templates are enabled. The corresponding fact sheet fields are automatically updated based on the values from other fields. For details, see [Calculations for AI Agents](https://help.sap.com/docs/leanix/ea/calculations-for-ai-agents?locale=en-US&state=PRODUCTION&version=CLOUD "Automatically calculate the business value of your AI agents.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio105fa840126347c384e2a74bf73736fb_LowRes.png)
Calculated Fields on an AI Agent Fact Sheet with Example Values
Use the predefined report AI Agents - Business Value to track the financial impact of AI agents across your landscape. You can find this report in the AI Agents collection on the reports page. The color coding indicates high-level business value. Detailed metrics are available in properties and tooltips.
  * Apply the Total Expected Cost Savings, Total Expected Revenue Increase, and Total Expected Risk Reduction views to understand expected increases and savings from AI agents. These metrics translate the potential of AI into tangible, monetary terms, showcasing both current achievements and the additional value that could be realized through further expansion of AI.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio7bedcf249a8146bbbbc0ce5a78bde2d4_LowRes.png)
AI Agents - Business Value Report: Total Expected Cost Savings
  * Apply the Usage view to analyze the usage of AI agents, which is defined based on users, session runs, sent messages, or other metrics. Usage indicates both actualized and future AI potential. High usage shows realized potential, while low usage indicates untapped opportunities. This helps organizations refine their strategies to reach AI's full potential.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiob23b3cf5630f4d04a5abb9708c57a610_LowRes.png)
AI Agents - Business Value Report: Usage


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
